library contentsquare;

import 'package:contentsquare/src/modules/gestures/cs_gesture_detector.dart';
import 'package:contentsquare/src/modules/screengraph/hit_test.dart';
import 'package:contentsquare_platform_interface/contentsquare_platform_interface.dart';
import 'package:flutter/material.dart';
import '../contentsquare.dart';
import 'package:flutter/widgets.dart';

/// ContentsquareRoot widget
///
/// Place it at the root of your app to provide your app with zoning features
class ContentsquareRoot extends StatelessWidget {
  /// ContensquareRoot widget constructor
  const ContentsquareRoot({Key? key, required this.child}) : super(key: key);

  /// Child widget
  final Widget child;

  void _handleGestureAtPosition({
    required CSGesture gestureType,
    required Offset position,
    CSGestureData? data,
  }) {
    final paths = getTVPAtHitPosition(position);

    // Send an event for every path found. Which will usually be only one.
    // See [hitPositionTVP] to understand why there might be several paths.
    for (var path in paths) {
      Contentsquare().sendTouchEvent(
        type: gestureType,
        version: version,
        data: TouchEventData(path: path, gestureData: data),
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    return CSGestureDetector(
      onTap: (Offset position) => _handleGestureAtPosition(
        position: position,
        gestureType: CSGesture.tap,
      ),
      onLongPress: (Offset position) => _handleGestureAtPosition(
        position: position,
        gestureType: CSGesture.longPress,
      ),
      onDrag: (Offset position, CSGestureData data) => _handleGestureAtPosition(
        position: position,
        gestureType: CSGesture.drag,
        data: data,
      ),
      onFlick: (Offset position, CSGestureData data) =>
          _handleGestureAtPosition(
        position: position,
        gestureType: CSGesture.flick,
        data: data,
      ),
      child: child,
    );
  }
}
