import 'dart:collection';

/// An extension on [UnmodifiableListView] that provides some utility methods
extension UnmodifiableListViewExtention on UnmodifiableListView<String> {
  /// Returns a copy of this list where duplicates and inclusions have been
  /// removed.
  ///
  /// For example ['a>b>c', 'a>b>c>d', 'a>b>c>d'] => ['a>b>c>d']
  UnmodifiableListView<String> removeDuplicatesAndInclusions() {
    final result = <String>[];
    for (final path in this) {
      var shouldAdd = true;
      for (int i = 0; i < result.length; i++) {
        final resultPath = result[i];
        if (resultPath.startsWith(path)) {
          shouldAdd = false;
          break;
        }

        if (path.startsWith(resultPath)) {
          result.removeAt(i);
        }
      }
      if (shouldAdd) {
        result.add(path);
      }
    }
    return UnmodifiableListView(result);
  }
}
