import 'package:contentsquare/src/modules/screengraph/painted_render_object_tree.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_test/flutter_test.dart';

import '../../../helpers/decompress_tvp.dart';
import 'fixtures/painted_render_object_tree_fixture.dart';
import 'fixtures/shared_fixture.dart';

main() {
  group(
    'getScreengraphFromRoot',
    () {
      testWidgets(
        'should return the correct screengraph after a scroll',
        (tester) async {
          await tester.pumpWidget(
            MaterialApp(
              home: Padding(
                padding: const EdgeInsets.all(10),
                child: Viewport(
                  offset: ViewportOffset.fixed(10),
                  slivers: [
                    SliverToBoxAdapter(
                      child: SizedBox(
                        height: 800,
                        child: Scaffold(
                          body: ListView.builder(
                            itemBuilder: (context, index) {
                              return ListTile(
                                title: SizedBox(
                                  height: 50,
                                  child: Text(
                                    'Text $index',
                                    key: ValueKey('Text $index'),
                                  ),
                                ),
                              );
                            },
                            itemCount: 30,
                          ),
                        ),
                      ),
                    ),
                  ],
                ),
              ),
            ),
          );

          // Scroll to invisible item
          final itemFinder = find.byKey(const ValueKey('Text 20'));
          await tester.scrollUntilVisible(itemFinder, 100);

          final screengraph = await getScreengraphFromRoot(
            nativePath: nativePath,
            pixelRatio: 1,
          );
          final decompressedScreengraph = decompressScreengraph(
            nativePath: nativePath,
            screengraphString: screengraph,
          );

          expect(decompressedScreengraph, screengraphAfterScroll);
        },
      );

      testWidgets(
        'should take into account the pixel ratio',
        (tester) async {
          await tester.pumpWidget(
            const MaterialApp(
              home: Scaffold(
                body: Center(
                  child: Text('Hello World'),
                ),
              ),
            ),
          );

          final _screengraphPixelRatio05 = await getScreengraphFromRoot(
            nativePath: nativePath,
            pixelRatio: 0.5,
          );
          final decompressedScreengraphPixelRatio05 = decompressScreengraph(
            nativePath: nativePath,
            screengraphString: _screengraphPixelRatio05,
          );

          final _screengraphPixelRatio2 = await getScreengraphFromRoot(
            nativePath: nativePath,
            pixelRatio: 2,
          );
          final decompressedScreengraphPixelRatio2 = decompressScreengraph(
            nativePath: nativePath,
            screengraphString: _screengraphPixelRatio2,
          );

          expect(decompressedScreengraphPixelRatio05, screengraphPixelRatio05);
          expect(decompressedScreengraphPixelRatio2, screengraphPixelRatio2);
          expect(_screengraphPixelRatio05, isNot(_screengraphPixelRatio2));
        },
      );
    },
  );
}
